@@ -12,11 +12,11 @@ App::HWD - Support functions for How We Doin'?, the project estimation and track
 
 =head1 VERSION
 
-Version 0.21_01
+Version 0.14
 
 =cut
 
-our $VERSION = '0.21_01';
+our $VERSION = '0.14';
 
 =head1 SYNOPSIS
 
@@ -36,8 +36,6 @@ Returns references to C<@tasks>, C<@work>, C<%tasks_by_id> and C<@errors>.
 =cut
 
 sub get_tasks_and_work {
-    my $handle = shift;
-
     my @tasks;
     my @work;
     my %tasks_by_id;
@@ -45,25 +43,9 @@ sub get_tasks_and_work {
 
     my @parents;
     my $curr_task;
-    my $lineno;
-    my $currfile;
-    for my $line ( <$handle> ) {
-        if ( !defined($currfile) ) {
-            $currfile = defined $ARGV ? $ARGV : "DATA";
-            $lineno = 1;
-        }
-        elsif ( !defined( $ARGV ) ) {
-            ++$lineno;
-        }
-        elsif ( $currfile eq $ARGV ) {
-            ++$lineno;
-        }
-        else {
-            $currfile = $ARGV;
-            $lineno = 1;
-        }
-
-        my $where = "line $lineno of $currfile";
+    my $lineno = 0;
+    for my $line ( @_ ) {
+        ++$lineno;
         chomp $line;
         next if $line =~ /^\s*#/;
         next if $line !~ /./;
@@ -74,18 +56,18 @@ sub get_tasks_and_work {
             if ( $level > 1 ) {
                 $parent = $parents[ $level - 1 ];
                 if ( !$parent ) {
-                    push( @errors, ucfirst( "$where has no parent: $line" ) );
+                    push( @errors, "Line $lineno has no parent: $line" );
                     next;
                 }
             }
-            my $task = App::HWD::Task->parse( $line, $parent, $where );
+            my $task = App::HWD::Task->parse( $line, $parent );
             if ( !$task ) {
-                push( @errors, "Can't parse at $where: $line" );
+                push( @errors, "Can't parse line $lineno: $line" );
                 next;
             }
             if ( $task->id ) {
                 if ( $tasks_by_id{ $task->id } ) {
-                    push( @errors, "Dupe task ID at $where: Task " . $task->id );
+                    push( @errors, "Dupe task ID on line $lineno: Task " . $task->id );
                     next;
                 }
                 $tasks_by_id{ $task->id } = $task;
@@ -103,27 +85,17 @@ sub get_tasks_and_work {
         else {
             my $work = App::HWD::Work->parse( $line );
             push( @work, $work );
-            if ( $work->task eq "^" ) {
-                if ( $curr_task ) {
-                    $curr_task->add_work( $work );
-                }
-                else {
-                    push( @errors, "Can't apply work to current task, because there is no current task" );
-                }
-            }
         }
     } # while
 
     # Validate the structure
     for my $task ( @tasks ) {
         if ( $task->estimate && $task->children ) {
-            my $where = $task->id || ("at " . $task->where);
-            push( @errors, "Task $where cannot have estimates, because it has children" );
+            push( @errors, sprintf( "Task %d cannot have estimates, because it has children", $task->id ) );
         }
     }
 
     for my $work ( @work ) {
-        next if $work->task eq "^"; # Already handled inline
         my $task = $tasks_by_id{ $work->task };
         if ( !$task ) {
             push( @errors, "No task ID " . $work->task );
@@ -132,7 +104,6 @@ sub get_tasks_and_work {
         $task->add_work( $work );
     }
 
-    # Get the work done in date order for each of the tasks
     $_->sort_work() for @tasks;
 
     return( \@tasks, \@work, \%tasks_by_id, \@errors );
@@ -158,7 +129,7 @@ and Luke Closs for features and patches.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006 Andy Lester, all rights reserved.
+Copyright 2005 Andy Lester, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
